@@ -1,20 +1,7 @@
-# -*- coding:utf-8 -*-
 #
 # Copyright 2014 Hewlett-Packard Development Company, L.P.
 #
-# Licensed under the Apache License, Version 2.0 (the "License"); you may
-# not use this file except in compliance with the License. You may obtain
-# a copy of the License at
-#
-#      http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
-# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
-# License for the specific language governing permissions and limitations
-# under the License.
-
-import _ast
+# SPDX-License-Identifier: Apache-2.0
 import ast
 import logging
 import os.path
@@ -25,14 +12,14 @@ try:
 except ImportError:
     import ConfigParser as configparser
 
-logger = logging.getLogger(__name__)
+LOG = logging.getLogger(__name__)
 
 
 """Various helper functions."""
 
 
 def _get_attr_qual_name(node, aliases):
-    '''Get a the full name for the attribute node.
+    """Get a the full name for the attribute node.
 
     This will resolve a pseudo-qualified name for the attribute
     rooted at node as long as all the deeper nodes are Names or
@@ -45,13 +32,13 @@ def _get_attr_qual_name(node, aliases):
     :param node: AST Name or Attribute node
     :param aliases: Import aliases dictionary
     :returns: Qualified name referred to by the attribute or name.
-    '''
-    if type(node) == _ast.Name:
+    """
+    if isinstance(node, ast.Name):
         if node.id in aliases:
             return aliases[node.id]
         return node.id
-    elif type(node) == _ast.Attribute:
-        name = '%s.%s' % (_get_attr_qual_name(node.value, aliases), node.attr)
+    elif isinstance(node, ast.Attribute):
+        name = f"{_get_attr_qual_name(node.value, aliases)}.{node.attr}"
         if name in aliases:
             return aliases[name]
         return name
@@ -60,11 +47,11 @@ def _get_attr_qual_name(node, aliases):
 
 
 def get_call_name(node, aliases):
-    if type(node.func) == _ast.Name:
-        if deepgetattr(node, 'func.id') in aliases:
-            return aliases[deepgetattr(node, 'func.id')]
-        return(deepgetattr(node, 'func.id'))
-    elif type(node.func) == _ast.Attribute:
+    if isinstance(node.func, ast.Name):
+        if deepgetattr(node, "func.id") in aliases:
+            return aliases[deepgetattr(node, "func.id")]
+        return deepgetattr(node, "func.id")
+    elif isinstance(node.func, ast.Attribute):
         return _get_attr_qual_name(node.func, aliases)
     else:
         return ""
@@ -76,26 +63,26 @@ def get_func_name(node):
 
 def get_qual_attr(node, aliases):
     prefix = ""
-    if type(node) == _ast.Attribute:
+    if isinstance(node, ast.Attribute):
         try:
-            val = deepgetattr(node, 'value.id')
+            val = deepgetattr(node, "value.id")
             if val in aliases:
                 prefix = aliases[val]
             else:
-                prefix = deepgetattr(node, 'value.id')
+                prefix = deepgetattr(node, "value.id")
         except Exception:
             # NOTE(tkelsey): degrade gracefully when we can't get the fully
             # qualified name for an attr, just return its base name.
             pass
 
-        return("%s.%s" % (prefix, node.attr))
+        return f"{prefix}.{node.attr}"
     else:
         return ""  # TODO(tkelsey): process other node types
 
 
 def deepgetattr(obj, attr):
     """Recurses through an attribute chain to get the ultimate value."""
-    for key in attr.split('.'):
+    for key in attr.split("."):
         obj = getattr(obj, key)
     return obj
 
@@ -106,33 +93,35 @@ class InvalidModulePath(Exception):
 
 class ConfigError(Exception):
     """Raised when the config file fails validation."""
+
     def __init__(self, message, config_file):
         self.config_file = config_file
-        self.message = "{0} : {1}".format(config_file, message)
-        super(ConfigError, self).__init__(self.message)
+        self.message = f"{config_file} : {message}"
+        super().__init__(self.message)
 
 
 class ProfileNotFound(Exception):
     """Raised when chosen profile cannot be found."""
+
     def __init__(self, config_file, profile):
         self.config_file = config_file
         self.profile = profile
-        message = 'Unable to find profile (%s) in config file: %s' % (
-            self.profile, self.config_file)
-        super(ProfileNotFound, self).__init__(message)
+        message = "Unable to find profile ({}) in config file: {}".format(
+            self.profile,
+            self.config_file,
+        )
+        super().__init__(message)
 
 
-def warnings_formatter(message,
-                       category=UserWarning,
-                       filename='',
-                       lineno=-1,
-                       line=''):
-    '''Monkey patch for warnings.warn to suppress cruft output.'''
-    return "{0}\n".format(message)
+def warnings_formatter(
+    message, category=UserWarning, filename="", lineno=-1, line=""
+):
+    """Monkey patch for warnings.warn to suppress cruft output."""
+    return f"{message}\n"
 
 
 def get_module_qualname_from_path(path):
-    '''Get the module's qualified name by analysis of the path.
+    """Get the module's qualified name by analysis of the path.
 
     Resolve the absolute pathname and eliminate symlinks. This could result in
     an incorrect name if symlinks are used to restructure the python lib
@@ -146,27 +135,29 @@ def get_module_qualname_from_path(path):
     :param: Path to module file. Relative paths will be resolved relative to
             current working directory.
     :return: fully qualified module name
-    '''
+    """
 
     (head, tail) = os.path.split(path)
-    if head == '' or tail == '':
-        raise InvalidModulePath('Invalid python file path: "%s"'
-                                ' Missing path or file name' % (path))
+    if head == "" or tail == "":
+        raise InvalidModulePath(
+            'Invalid python file path: "%s"'
+            " Missing path or file name" % (path)
+        )
 
     qname = [os.path.splitext(tail)[0]]
-    while head not in ['/', '.']:
-        if os.path.isfile(os.path.join(head, '__init__.py')):
+    while head not in ["/", ".", ""]:
+        if os.path.isfile(os.path.join(head, "__init__.py")):
             (head, tail) = os.path.split(head)
             qname.insert(0, tail)
         else:
             break
 
-    qualname = '.'.join(qname)
+    qualname = ".".join(qname)
     return qualname
 
 
 def namespace_path_join(base, name):
-    '''Extend the current namespace path with an additional name
+    """Extend the current namespace path with an additional name
 
     Take a namespace path (i.e., package.module.class) and extends it
     with an additional name (i.e., package.module.class.subclass).
@@ -176,12 +167,12 @@ def namespace_path_join(base, name):
     :param name: (String) The new name to append to the base path.
     :returns: (String) A new namespace path resulting from combination of
               base and name.
-    '''
-    return '%s.%s' % (base, name)
+    """
+    return f"{base}.{name}"
 
 
 def namespace_path_split(path):
-    '''Split the namespace path into a pair (head, tail).
+    """Split the namespace path into a pair (head, tail).
 
     Tail will be the last namespace path component and head will
     be everything leading up to that in the path. This is similar to
@@ -190,12 +181,12 @@ def namespace_path_split(path):
     :param path: (String) A namespace path.
     :returns: (String, String) A tuple where the first component is the base
               path and the second is the last path component.
-    '''
-    return tuple(path.rsplit('.', 1))
+    """
+    return tuple(path.rsplit(".", 1))
 
 
 def escaped_bytes_representation(b):
-    '''PY3 bytes need escaping for comparison with other strings.
+    """PY3 bytes need escaping for comparison with other strings.
 
     In practice it turns control characters into acceptable codepoints then
     encodes them into bytes again to turn unprintable bytes into printable
@@ -203,29 +194,28 @@ def escaped_bytes_representation(b):
 
     This is safe to do for the whole range 0..255 and result matches
     unicode_escape on a unicode string.
-    '''
-    return b.decode('unicode_escape').encode('unicode_escape')
+    """
+    return b.decode("unicode_escape").encode("unicode_escape")
 
 
 def linerange(node):
     """Get line number range from a node."""
-    strip = {"body": None, "orelse": None,
-             "handlers": None, "finalbody": None}
+    strip = {"body": None, "orelse": None, "handlers": None, "finalbody": None}
     for key in strip.keys():
         if hasattr(node, key):
             strip[key] = getattr(node, key)
-            setattr(node, key, [])
+            node.key = []
 
     lines_min = 9999999999
     lines_max = -1
     for n in ast.walk(node):
-        if hasattr(n, 'lineno'):
+        if hasattr(n, "lineno"):
             lines_min = min(lines_min, n.lineno)
             lines_max = max(lines_max, n.lineno)
 
     for key in strip.keys():
         if strip[key] is not None:
-            setattr(node, key, strip[key])
+            node.key = strip[key]
 
     if lines_max > -1:
         return list(range(lines_min, lines_max + 1))
@@ -236,16 +226,18 @@ def linerange_fix(node):
     """Try and work around a known Python bug with multi-line strings."""
     # deal with multiline strings lineno behavior (Python issue #16806)
     lines = linerange(node)
-    if hasattr(node, 'sibling') and hasattr(node.sibling, 'lineno'):
+    if hasattr(node, "_bandit_sibling") and hasattr(
+        node._bandit_sibling, "lineno"
+    ):
         start = min(lines)
-        delta = node.sibling.lineno - start
+        delta = node._bandit_sibling.lineno - start
         if delta > 1:
-            return list(range(start, node.sibling.lineno))
+            return list(range(start, node._bandit_sibling.lineno))
     return lines
 
 
 def concat_string(node, stop=None):
-    '''Builds a string from a ast.BinOp chain.
+    """Builds a string from a ast.BinOp chain.
 
     This will build a string from a series of ast.Str nodes wrapped in
     ast.BinOp nodes. Something like "a" + "b" + "c" or "a %s" % val etc.
@@ -254,28 +246,31 @@ def concat_string(node, stop=None):
     :param node: (ast.Str or ast.BinOp) The node to process
     :param stop: (ast.Str or ast.BinOp) Optional base node to stop at
     :returns: (Tuple) the root node of the expression, the string value
-    '''
+    """
+
     def _get(node, bits, stop=None):
         if node != stop:
             bits.append(
                 _get(node.left, bits, stop)
                 if isinstance(node.left, ast.BinOp)
-                else node.left)
+                else node.left
+            )
             bits.append(
                 _get(node.right, bits, stop)
                 if isinstance(node.right, ast.BinOp)
-                else node.right)
+                else node.right
+            )
 
     bits = [node]
-    while isinstance(node.parent, ast.BinOp):
-        node = node.parent
+    while isinstance(node._bandit_parent, ast.BinOp):
+        node = node._bandit_parent
     if isinstance(node, ast.BinOp):
         _get(node, bits, stop)
     return (node, " ".join([x.s for x in bits if isinstance(x, ast.Str)]))
 
 
 def get_called_name(node):
-    '''Get a function name from an ast.Call node.
+    """Get a function name from an ast.Call node.
 
     An ast.Call node representing a method call with present differently to one
     wrapping a function call: thing.call() vs call(). This helper will grab the
@@ -283,34 +278,34 @@ def get_called_name(node):
 
     :param node: (ast.Call) the call node
     :returns: (String) the function name
-    '''
+    """
     func = node.func
     try:
-        return (func.attr if isinstance(func, ast.Attribute) else func.id)
+        return func.attr if isinstance(func, ast.Attribute) else func.id
     except AttributeError:
         return ""
 
 
 def get_path_for_function(f):
-    '''Get the path of the file where the function is defined.
+    """Get the path of the file where the function is defined.
 
     :returns: the path, or None if one could not be found or f is not a real
         function
-    '''
+    """
 
     if hasattr(f, "__module__"):
         module_name = f.__module__
     elif hasattr(f, "im_func"):
         module_name = f.im_func.__module__
     else:
-        logger.warning("Cannot resolve file where %s is defined", f)
+        LOG.warning("Cannot resolve file where %s is defined", f)
         return None
 
     module = sys.modules[module_name]
     if hasattr(module, "__file__"):
         return module.__file__
     else:
-        logger.warning("Cannot resolve file path for module %s", module_name)
+        LOG.warning("Cannot resolve file path for module %s", module_name)
         return None
 
 
@@ -318,17 +313,19 @@ def parse_ini_file(f_loc):
     config = configparser.ConfigParser()
     try:
         config.read(f_loc)
-        return {k: v for k, v in config.items('bandit')}
+        return {k: v for k, v in config.items("bandit")}
 
     except (configparser.Error, KeyError, TypeError):
-        logger.warning("Unable to parse config file %s or missing [bandit] "
-                       "section", f_loc)
+        LOG.warning(
+            "Unable to parse config file %s or missing [bandit] " "section",
+            f_loc,
+        )
 
     return None
 
 
 def check_ast_node(name):
-    'Check if the given name is that of a valid AST node.'
+    "Check if the given name is that of a valid AST node."
     try:
         node = getattr(ast, name)
         if issubclass(node, ast.AST):
